import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.leader_qualifier_model_comparison_type import LeaderQualifierModelComparisonType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.leader_qualifier_model_leaders_criteria import LeaderQualifierModelLeadersCriteria
    from ..models.leader_qualifier_model_organization import LeaderQualifierModelOrganization


T = TypeVar("T", bound="LeaderQualifierModel")


@_attrs_define
class LeaderQualifierModel:
    """
    Attributes:
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        qualifier_id (Union[Unset, UUID]): The unique identifier of the leader qualifier Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, LeaderQualifierModelOrganization]): The organization that this LeaderQualifier
            belongs to
        leader_criteria_id (Union[Unset, UUID]): The unique identifier of the ~LeaderCriteria~ Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        leaders_criteria (Union[Unset, LeaderQualifierModelLeadersCriteria]): The ~LeaderCriteria~ linked to this record
        statistic_field (Union[Unset, str]): The statistic field that this qualifier is for.
        comparison_field (Union[Unset, str]): The statistic field to compare against.
        comparison_type (Union[Unset, LeaderQualifierModelComparisonType]): Comparison type for the qualifier
            >- `EQUAL` Equal
            >- `GREATER_THAN` Greater than
            >- `GREATER_THAN_EQUAL` Greater than or equal
            >- `LESS_THAN` Less than
            >- `LESS_THAN_EQUAL` Less than or equal
             Example: GREATER_THAN.
        comparison_value (Union[Unset, float]): Comparison value for the qualifier
    """

    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    qualifier_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "LeaderQualifierModelOrganization"] = UNSET
    leader_criteria_id: Union[Unset, UUID] = UNSET
    leaders_criteria: Union[Unset, "LeaderQualifierModelLeadersCriteria"] = UNSET
    statistic_field: Union[Unset, str] = UNSET
    comparison_field: Union[Unset, str] = UNSET
    comparison_type: Union[Unset, LeaderQualifierModelComparisonType] = UNSET
    comparison_value: Union[Unset, float] = UNSET

    def to_dict(self) -> dict[str, Any]:
        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        qualifier_id: Union[Unset, str] = UNSET
        if not isinstance(self.qualifier_id, Unset):
            qualifier_id = str(self.qualifier_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        leader_criteria_id: Union[Unset, str] = UNSET
        if not isinstance(self.leader_criteria_id, Unset):
            leader_criteria_id = str(self.leader_criteria_id)

        leaders_criteria: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.leaders_criteria, Unset):
            leaders_criteria = self.leaders_criteria.to_dict()

        statistic_field = self.statistic_field

        comparison_field = self.comparison_field

        comparison_type: Union[Unset, str] = UNSET
        if not isinstance(self.comparison_type, Unset):
            comparison_type = self.comparison_type.value

        comparison_value = self.comparison_value

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if qualifier_id is not UNSET:
            field_dict["qualifierId"] = qualifier_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if leader_criteria_id is not UNSET:
            field_dict["leaderCriteriaId"] = leader_criteria_id
        if leaders_criteria is not UNSET:
            field_dict["leadersCriteria"] = leaders_criteria
        if statistic_field is not UNSET:
            field_dict["statisticField"] = statistic_field
        if comparison_field is not UNSET:
            field_dict["comparisonField"] = comparison_field
        if comparison_type is not UNSET:
            field_dict["comparisonType"] = comparison_type
        if comparison_value is not UNSET:
            field_dict["comparisonValue"] = comparison_value

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.leader_qualifier_model_leaders_criteria import LeaderQualifierModelLeadersCriteria
        from ..models.leader_qualifier_model_organization import LeaderQualifierModelOrganization

        d = dict(src_dict)
        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        _qualifier_id = d.pop("qualifierId", UNSET)
        qualifier_id: Union[Unset, UUID]
        if isinstance(_qualifier_id, Unset):
            qualifier_id = UNSET
        else:
            qualifier_id = UUID(_qualifier_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, LeaderQualifierModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = LeaderQualifierModelOrganization.from_dict(_organization)

        _leader_criteria_id = d.pop("leaderCriteriaId", UNSET)
        leader_criteria_id: Union[Unset, UUID]
        if isinstance(_leader_criteria_id, Unset):
            leader_criteria_id = UNSET
        else:
            leader_criteria_id = UUID(_leader_criteria_id)

        _leaders_criteria = d.pop("leadersCriteria", UNSET)
        leaders_criteria: Union[Unset, LeaderQualifierModelLeadersCriteria]
        if isinstance(_leaders_criteria, Unset):
            leaders_criteria = UNSET
        else:
            leaders_criteria = LeaderQualifierModelLeadersCriteria.from_dict(_leaders_criteria)

        statistic_field = d.pop("statisticField", UNSET)

        comparison_field = d.pop("comparisonField", UNSET)

        _comparison_type = d.pop("comparisonType", UNSET)
        comparison_type: Union[Unset, LeaderQualifierModelComparisonType]
        if isinstance(_comparison_type, Unset):
            comparison_type = UNSET
        else:
            comparison_type = LeaderQualifierModelComparisonType(_comparison_type)

        comparison_value = d.pop("comparisonValue", UNSET)

        leader_qualifier_model = cls(
            updated=updated,
            added=added,
            qualifier_id=qualifier_id,
            organization_id=organization_id,
            organization=organization,
            leader_criteria_id=leader_criteria_id,
            leaders_criteria=leaders_criteria,
            statistic_field=statistic_field,
            comparison_field=comparison_field,
            comparison_type=comparison_type,
            comparison_value=comparison_value,
        )

        return leader_qualifier_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.video_file_model_content import VideoFileModelContent
from ..models.video_file_model_feed_type import VideoFileModelFeedType
from ..models.video_file_model_format import VideoFileModelFormat
from ..models.video_file_model_origin_type_1 import VideoFileModelOriginType1
from ..models.video_file_model_origin_type_2_type_1 import VideoFileModelOriginType2Type1
from ..models.video_file_model_origin_type_3_type_1 import VideoFileModelOriginType3Type1
from ..models.video_file_model_resolution import VideoFileModelResolution
from ..models.video_file_model_status_type_1 import VideoFileModelStatusType1
from ..models.video_file_model_status_type_2_type_1 import VideoFileModelStatusType2Type1
from ..models.video_file_model_status_type_3_type_1 import VideoFileModelStatusType3Type1
from ..models.video_file_model_storage_provider_type_1 import VideoFileModelStorageProviderType1
from ..models.video_file_model_storage_provider_type_2_type_1 import VideoFileModelStorageProviderType2Type1
from ..models.video_file_model_storage_provider_type_3_type_1 import VideoFileModelStorageProviderType3Type1
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.video_file_model_fixture import VideoFileModelFixture
    from ..models.video_file_model_organization import VideoFileModelOrganization


T = TypeVar("T", bound="VideoFileModel")


@_attrs_define
class VideoFileModel:
    """
    Attributes:
        video_id (Union[Unset, UUID]): The unique identifier of the video Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, VideoFileModelOrganization]): The organization that this video file belongs to
        provider (Union[Unset, str]): The code for the provider of the file Example: Test Provider.
        locale (Union[Unset, str]): The locale of the video Example: fr-FR.
        source_number (Union[Unset, int]): Unique identifier for the video source. This is unique for the
            provider/fixtureId/locale combination.  Unless the provider is supplying multiple sources per fixture/locale
            then this is normally 1. Default: 1. Example: 1.
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, VideoFileModelFixture]): The match
        resolution (Union[Unset, VideoFileModelResolution]): The resolution of the video input
            >- `1080` 1920 x 1080
            >- `288` 512 x 288
            >- `720` 1280 x 720
             Example: 720.
        name (Union[Unset, str]): The name/description of the video file
        feed_type (Union[Unset, VideoFileModelFeedType]): Type of video input
            >- `ADDITIONAL_ANGLE` Additional angle
            >- `LOW_LATENCY` Low Latency
            >- `PRIMARY` Primary
             Example: PRIMARY.
        content (Union[Unset, VideoFileModelContent]): Content of the stream
            >- `CLEAN` Output signal is the same as the input signal
            >- `PROGRAM` Score overlays and other enhancements have been added to the stream
             Example: CLEAN.
        fps (Union[Unset, int]): fps for the video stream Default: 25. Example: 25.
        origin (Union[None, Unset, VideoFileModelOriginType1, VideoFileModelOriginType2Type1,
            VideoFileModelOriginType3Type1]): The origin of the video file
            >- None None
            >- `STREAM` Streamed
            >- `UPLOAD` Uploaded
            >- `VENUE` Recorded in venue
             Example: STREAM.
        format_ (Union[Unset, VideoFileModelFormat]): The format of the video file
            >- `HLS` A HLS play list
            >- `MP4` One MP4 file
             Example: HLS.
        storage_provider (Union[None, Unset, VideoFileModelStorageProviderType1,
            VideoFileModelStorageProviderType2Type1, VideoFileModelStorageProviderType3Type1]): Where the video file is
            stored?
            >- None None
            >- `5STREAM` 5stream
            >- `AV_SPORTRADAR` AV Sportradar
            >- `KEEMOTION` Keemotion
            >- `SYNERGY` Synergy
             Example: KEEMOTION.
        size (Union[None, Unset, float]): Size (Mb) of the video (only given if a single file) Example: 1024.2.
        length (Union[None, Unset, float]): Lenth (mins) of the video Example: 123.4.
        encoding (Union[Unset, str]): How is the video/audio encoded. codecs etc. Example: H.264/AAC.
        status (Union[None, Unset, VideoFileModelStatusType1, VideoFileModelStatusType2Type1,
            VideoFileModelStatusType3Type1]): What is the status of the file?
            >- None None
            >- `AVAILABLE` Available for access
            >- `BUILDABLE` Not currently available - but can be built on request
            >- `PENDING` Being added - some parts may be available
             Example: AVAILABLE.
        start_time (Union[Unset, datetime.datetime]): The time this recording started (UTC)
        expiry (Union[None, Unset, datetime.datetime]): When does this file expire? (UTC)
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    video_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "VideoFileModelOrganization"] = UNSET
    provider: Union[Unset, str] = UNSET
    locale: Union[Unset, str] = UNSET
    source_number: Union[Unset, int] = 1
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "VideoFileModelFixture"] = UNSET
    resolution: Union[Unset, VideoFileModelResolution] = UNSET
    name: Union[Unset, str] = UNSET
    feed_type: Union[Unset, VideoFileModelFeedType] = UNSET
    content: Union[Unset, VideoFileModelContent] = UNSET
    fps: Union[Unset, int] = 25
    origin: Union[
        None, Unset, VideoFileModelOriginType1, VideoFileModelOriginType2Type1, VideoFileModelOriginType3Type1
    ] = UNSET
    format_: Union[Unset, VideoFileModelFormat] = UNSET
    storage_provider: Union[
        None,
        Unset,
        VideoFileModelStorageProviderType1,
        VideoFileModelStorageProviderType2Type1,
        VideoFileModelStorageProviderType3Type1,
    ] = UNSET
    size: Union[None, Unset, float] = UNSET
    length: Union[None, Unset, float] = UNSET
    encoding: Union[Unset, str] = UNSET
    status: Union[
        None, Unset, VideoFileModelStatusType1, VideoFileModelStatusType2Type1, VideoFileModelStatusType3Type1
    ] = UNSET
    start_time: Union[Unset, datetime.datetime] = UNSET
    expiry: Union[None, Unset, datetime.datetime] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        video_id: Union[Unset, str] = UNSET
        if not isinstance(self.video_id, Unset):
            video_id = str(self.video_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        provider = self.provider

        locale = self.locale

        source_number = self.source_number

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        resolution: Union[Unset, str] = UNSET
        if not isinstance(self.resolution, Unset):
            resolution = self.resolution.value

        name = self.name

        feed_type: Union[Unset, str] = UNSET
        if not isinstance(self.feed_type, Unset):
            feed_type = self.feed_type.value

        content: Union[Unset, str] = UNSET
        if not isinstance(self.content, Unset):
            content = self.content.value

        fps = self.fps

        origin: Union[None, Unset, str]
        if isinstance(self.origin, Unset):
            origin = UNSET
        elif isinstance(self.origin, VideoFileModelOriginType1):
            origin = self.origin.value
        elif isinstance(self.origin, VideoFileModelOriginType2Type1):
            origin = self.origin.value
        elif isinstance(self.origin, VideoFileModelOriginType3Type1):
            origin = self.origin.value
        else:
            origin = self.origin

        format_: Union[Unset, str] = UNSET
        if not isinstance(self.format_, Unset):
            format_ = self.format_.value

        storage_provider: Union[None, Unset, str]
        if isinstance(self.storage_provider, Unset):
            storage_provider = UNSET
        elif isinstance(self.storage_provider, VideoFileModelStorageProviderType1):
            storage_provider = self.storage_provider.value
        elif isinstance(self.storage_provider, VideoFileModelStorageProviderType2Type1):
            storage_provider = self.storage_provider.value
        elif isinstance(self.storage_provider, VideoFileModelStorageProviderType3Type1):
            storage_provider = self.storage_provider.value
        else:
            storage_provider = self.storage_provider

        size: Union[None, Unset, float]
        if isinstance(self.size, Unset):
            size = UNSET
        else:
            size = self.size

        length: Union[None, Unset, float]
        if isinstance(self.length, Unset):
            length = UNSET
        else:
            length = self.length

        encoding = self.encoding

        status: Union[None, Unset, str]
        if isinstance(self.status, Unset):
            status = UNSET
        elif isinstance(self.status, VideoFileModelStatusType1):
            status = self.status.value
        elif isinstance(self.status, VideoFileModelStatusType2Type1):
            status = self.status.value
        elif isinstance(self.status, VideoFileModelStatusType3Type1):
            status = self.status.value
        else:
            status = self.status

        start_time: Union[Unset, str] = UNSET
        if not isinstance(self.start_time, Unset):
            start_time = self.start_time.isoformat()

        expiry: Union[None, Unset, str]
        if isinstance(self.expiry, Unset):
            expiry = UNSET
        elif isinstance(self.expiry, datetime.datetime):
            expiry = self.expiry.isoformat()
        else:
            expiry = self.expiry

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if video_id is not UNSET:
            field_dict["videoId"] = video_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if provider is not UNSET:
            field_dict["provider"] = provider
        if locale is not UNSET:
            field_dict["locale"] = locale
        if source_number is not UNSET:
            field_dict["sourceNumber"] = source_number
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if resolution is not UNSET:
            field_dict["resolution"] = resolution
        if name is not UNSET:
            field_dict["name"] = name
        if feed_type is not UNSET:
            field_dict["feedType"] = feed_type
        if content is not UNSET:
            field_dict["content"] = content
        if fps is not UNSET:
            field_dict["fps"] = fps
        if origin is not UNSET:
            field_dict["origin"] = origin
        if format_ is not UNSET:
            field_dict["format"] = format_
        if storage_provider is not UNSET:
            field_dict["storageProvider"] = storage_provider
        if size is not UNSET:
            field_dict["size"] = size
        if length is not UNSET:
            field_dict["length"] = length
        if encoding is not UNSET:
            field_dict["encoding"] = encoding
        if status is not UNSET:
            field_dict["status"] = status
        if start_time is not UNSET:
            field_dict["startTime"] = start_time
        if expiry is not UNSET:
            field_dict["expiry"] = expiry
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.video_file_model_fixture import VideoFileModelFixture
        from ..models.video_file_model_organization import VideoFileModelOrganization

        d = dict(src_dict)
        _video_id = d.pop("videoId", UNSET)
        video_id: Union[Unset, UUID]
        if isinstance(_video_id, Unset):
            video_id = UNSET
        else:
            video_id = UUID(_video_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, VideoFileModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = VideoFileModelOrganization.from_dict(_organization)

        provider = d.pop("provider", UNSET)

        locale = d.pop("locale", UNSET)

        source_number = d.pop("sourceNumber", UNSET)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, VideoFileModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = VideoFileModelFixture.from_dict(_fixture)

        _resolution = d.pop("resolution", UNSET)
        resolution: Union[Unset, VideoFileModelResolution]
        if isinstance(_resolution, Unset):
            resolution = UNSET
        else:
            resolution = VideoFileModelResolution(_resolution)

        name = d.pop("name", UNSET)

        _feed_type = d.pop("feedType", UNSET)
        feed_type: Union[Unset, VideoFileModelFeedType]
        if isinstance(_feed_type, Unset):
            feed_type = UNSET
        else:
            feed_type = VideoFileModelFeedType(_feed_type)

        _content = d.pop("content", UNSET)
        content: Union[Unset, VideoFileModelContent]
        if isinstance(_content, Unset):
            content = UNSET
        else:
            content = VideoFileModelContent(_content)

        fps = d.pop("fps", UNSET)

        def _parse_origin(
            data: object,
        ) -> Union[
            None, Unset, VideoFileModelOriginType1, VideoFileModelOriginType2Type1, VideoFileModelOriginType3Type1
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                origin_type_1 = VideoFileModelOriginType1(data)

                return origin_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                origin_type_2_type_1 = VideoFileModelOriginType2Type1(data)

                return origin_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                origin_type_3_type_1 = VideoFileModelOriginType3Type1(data)

                return origin_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    None,
                    Unset,
                    VideoFileModelOriginType1,
                    VideoFileModelOriginType2Type1,
                    VideoFileModelOriginType3Type1,
                ],
                data,
            )

        origin = _parse_origin(d.pop("origin", UNSET))

        _format_ = d.pop("format", UNSET)
        format_: Union[Unset, VideoFileModelFormat]
        if isinstance(_format_, Unset):
            format_ = UNSET
        else:
            format_ = VideoFileModelFormat(_format_)

        def _parse_storage_provider(
            data: object,
        ) -> Union[
            None,
            Unset,
            VideoFileModelStorageProviderType1,
            VideoFileModelStorageProviderType2Type1,
            VideoFileModelStorageProviderType3Type1,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                storage_provider_type_1 = VideoFileModelStorageProviderType1(data)

                return storage_provider_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                storage_provider_type_2_type_1 = VideoFileModelStorageProviderType2Type1(data)

                return storage_provider_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                storage_provider_type_3_type_1 = VideoFileModelStorageProviderType3Type1(data)

                return storage_provider_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    None,
                    Unset,
                    VideoFileModelStorageProviderType1,
                    VideoFileModelStorageProviderType2Type1,
                    VideoFileModelStorageProviderType3Type1,
                ],
                data,
            )

        storage_provider = _parse_storage_provider(d.pop("storageProvider", UNSET))

        def _parse_size(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        size = _parse_size(d.pop("size", UNSET))

        def _parse_length(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        length = _parse_length(d.pop("length", UNSET))

        encoding = d.pop("encoding", UNSET)

        def _parse_status(
            data: object,
        ) -> Union[
            None, Unset, VideoFileModelStatusType1, VideoFileModelStatusType2Type1, VideoFileModelStatusType3Type1
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_1 = VideoFileModelStatusType1(data)

                return status_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_2_type_1 = VideoFileModelStatusType2Type1(data)

                return status_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_3_type_1 = VideoFileModelStatusType3Type1(data)

                return status_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    None,
                    Unset,
                    VideoFileModelStatusType1,
                    VideoFileModelStatusType2Type1,
                    VideoFileModelStatusType3Type1,
                ],
                data,
            )

        status = _parse_status(d.pop("status", UNSET))

        _start_time = d.pop("startTime", UNSET)
        start_time: Union[Unset, datetime.datetime]
        if isinstance(_start_time, Unset):
            start_time = UNSET
        else:
            start_time = isoparse(_start_time)

        def _parse_expiry(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                expiry_type_0 = isoparse(data)

                return expiry_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        expiry = _parse_expiry(d.pop("expiry", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        video_file_model = cls(
            video_id=video_id,
            organization_id=organization_id,
            organization=organization,
            provider=provider,
            locale=locale,
            source_number=source_number,
            fixture_id=fixture_id,
            fixture=fixture,
            resolution=resolution,
            name=name,
            feed_type=feed_type,
            content=content,
            fps=fps,
            origin=origin,
            format_=format_,
            storage_provider=storage_provider,
            size=size,
            length=length,
            encoding=encoding,
            status=status,
            start_time=start_time,
            expiry=expiry,
            updated=updated,
            added=added,
        )

        return video_file_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.club_external_ids_model_entity_group import ClubExternalIdsModelEntityGroup
    from ..models.club_external_ids_model_organization import ClubExternalIdsModelOrganization


T = TypeVar("T", bound="ClubExternalIdsModel")


@_attrs_define
class ClubExternalIdsModel:
    """
    Attributes:
        entity_group_external_id (Union[Unset, UUID]): The unique identifier of the external ids Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, ClubExternalIdsModelOrganization]): The organization that this club external ids
            belongs to
        entity_group_id (Union[Unset, UUID]): The club that this team belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_group (Union[Unset, ClubExternalIdsModelEntityGroup]): The club that this team belongs to
        source (Union[Unset, str]): The source of the external Id Example: urn:sources:sportradar.com.
        source_type (Union[Unset, str]): Source type of external Id
        source_external_id (Union[Unset, str]): Identifier of external source Example: SR:123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    entity_group_external_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "ClubExternalIdsModelOrganization"] = UNSET
    entity_group_id: Union[Unset, UUID] = UNSET
    entity_group: Union[Unset, "ClubExternalIdsModelEntityGroup"] = UNSET
    source: Union[Unset, str] = UNSET
    source_type: Union[Unset, str] = UNSET
    source_external_id: Union[Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        entity_group_external_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_group_external_id, Unset):
            entity_group_external_id = str(self.entity_group_external_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        entity_group_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_group_id, Unset):
            entity_group_id = str(self.entity_group_id)

        entity_group: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity_group, Unset):
            entity_group = self.entity_group.to_dict()

        source = self.source

        source_type = self.source_type

        source_external_id = self.source_external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if entity_group_external_id is not UNSET:
            field_dict["entityGroupExternalId"] = entity_group_external_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if entity_group is not UNSET:
            field_dict["entityGroup"] = entity_group
        if source is not UNSET:
            field_dict["source"] = source
        if source_type is not UNSET:
            field_dict["sourceType"] = source_type
        if source_external_id is not UNSET:
            field_dict["sourceExternalId"] = source_external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.club_external_ids_model_entity_group import ClubExternalIdsModelEntityGroup
        from ..models.club_external_ids_model_organization import ClubExternalIdsModelOrganization

        d = dict(src_dict)
        _entity_group_external_id = d.pop("entityGroupExternalId", UNSET)
        entity_group_external_id: Union[Unset, UUID]
        if isinstance(_entity_group_external_id, Unset):
            entity_group_external_id = UNSET
        else:
            entity_group_external_id = UUID(_entity_group_external_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, ClubExternalIdsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = ClubExternalIdsModelOrganization.from_dict(_organization)

        _entity_group_id = d.pop("entityGroupId", UNSET)
        entity_group_id: Union[Unset, UUID]
        if isinstance(_entity_group_id, Unset):
            entity_group_id = UNSET
        else:
            entity_group_id = UUID(_entity_group_id)

        _entity_group = d.pop("entityGroup", UNSET)
        entity_group: Union[Unset, ClubExternalIdsModelEntityGroup]
        if isinstance(_entity_group, Unset):
            entity_group = UNSET
        else:
            entity_group = ClubExternalIdsModelEntityGroup.from_dict(_entity_group)

        source = d.pop("source", UNSET)

        source_type = d.pop("sourceType", UNSET)

        source_external_id = d.pop("sourceExternalId", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        club_external_ids_model = cls(
            entity_group_external_id=entity_group_external_id,
            organization_id=organization_id,
            organization=organization,
            entity_group_id=entity_group_id,
            entity_group=entity_group,
            source=source,
            source_type=source_type,
            source_external_id=source_external_id,
            updated=updated,
            added=added,
        )

        return club_external_ids_model



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="StandingModelCalculatedAdditionalProperty")


@_attrs_define
class StandingModelCalculatedAdditionalProperty:
    """Type of points

    Example:
        default

    Attributes:
        played (Union[Unset, float]): Fixtures played
        played_home (Union[Unset, float]): Fixtures played at home
        played_away (Union[Unset, float]): Fixtures played away
        washouts (Union[Unset, float]): Number of washed out fixtures
        wins (Union[Unset, float]): Fixtures Won
        wins_home (Union[Unset, float]): Fixtures Won at home
        wins_away (Union[Unset, float]): Fixtures Won away
        wins_secondary_score (Union[Unset, float]): Fixtures Won via Secondary Score
        wins_secondary_score_home (Union[Unset, float]): Fixtures Won at home via Secondary Score
        wins_secondary_score_away (Union[Unset, float]): Fixtures Won away via Secondary Score
        losses (Union[Unset, float]): Fixtures Lost
        losses_home (Union[Unset, float]): Fixtures Lost at home
        losses_away (Union[Unset, float]): Fixtures Lost away
        losses_secondary_score (Union[Unset, float]): Fixtures Lost via Secondary Score
        losses_secondary_score_home (Union[Unset, float]): Fixtures Lost at home via Secondary Score
        losses_secondary_score_away (Union[Unset, float]): Fixtures Lost away via Secondary Score
        draws (Union[Unset, float]): Fixtures Drawn
        draws_home (Union[Unset, float]): Fixtures Drawn at home
        draws_away (Union[Unset, float]): Fixtures Drawn away
        byes (Union[Unset, float]): Fixtures Byes
        forfeits_given (Union[Unset, float]): Fixtures Forfeits Given
        forfeits_won_by (Union[Unset, float]): Fixtures Forfeits Won
        win_percentage_display (Union[Unset, float]): Win Percentage (wins/played) (Display Value)
        win_percentage_home_display (Union[Unset, float]): Win Percentage Home (wins/played) (Display Value)
        win_percentage_away_display (Union[Unset, float]): Win Percentage Away (wins/played) (Display Value)
        win_percentage (Union[Unset, float]): Win Percentage (wins/played)
        win_percentage_home (Union[Unset, float]): Win Percentage Home (wins/played)
        win_percentage_away (Union[Unset, float]): Win Percentage Away (wins/played)
        scored_for (Union[Unset, float]): Scored For
        scored_for_home (Union[Unset, float]): Scored For at home
        scored_for_away (Union[Unset, float]): Scored For away
        scored_for_average (Union[Unset, float]): Scored For Average
        scored_for_home_average (Union[Unset, float]): Scored For Average at home
        scored_for_away_average (Union[Unset, float]): Scored For Average away
        scored_against (Union[Unset, float]): Scored Against
        scored_against_home (Union[Unset, float]): Scored Against at home
        scored_against_away (Union[Unset, float]): Scored Against away
        scored_against_average (Union[Unset, float]): Scored Against Average
        scored_against_home_average (Union[Unset, float]): Scored Against Average at home
        scored_against_away_average (Union[Unset, float]): Scored Against Average away
        percentage_display (Union[Unset, float]): For versus Against (Display Value)
        percentage_home_display (Union[Unset, float]): For versus Against at home (Display Value)
        percentage_away_display (Union[Unset, float]): For versus Against away (Display Value)
        percentage (Union[Unset, float]): For versus Against
        percentage_home (Union[Unset, float]): For versus Against at home
        percentage_away (Union[Unset, float]): For versus Against away
        point_difference (Union[Unset, float]): Point Difference for competitor
        point_difference_home (Union[Unset, float]): Point Difference for competitor at Home
        point_difference_away (Union[Unset, float]): Point Difference for competitor away
        lowest_score_for (Union[None, Unset, float]): Lowest Score for competitor
        lowest_score_for_home (Union[None, Unset, float]): Lowest Score for competitor at Home
        lowest_score_for_away (Union[None, Unset, float]): Lowest Score for competitor away
        highest_score_for (Union[None, Unset, float]): Highest Score for competitor
        highest_score_for_home (Union[None, Unset, float]): Highest Score for competitor at Home
        highest_score_for_away (Union[None, Unset, float]): Highest Score for competitor away
        lowest_score_against (Union[None, Unset, float]): Lowest Score against competitor
        lowest_score_against_home (Union[None, Unset, float]): Lowest Score against competitor at Home
        lowest_score_against_away (Union[None, Unset, float]): Lowest Score against competitor away
        highest_score_against (Union[None, Unset, float]): Highest Score against competitor
        highest_score_against_home (Union[None, Unset, float]): Highest Score against competitor at Home
        highest_score_against_away (Union[None, Unset, float]): Highest Score against competitor away
        streak (Union[Unset, float]): Winning streak for competitor
        streak_home (Union[Unset, float]): Winning streak for competitor at Home
        streak_away (Union[Unset, float]): Winning streak for competitor away
        result_string (Union[Unset, str]): Result string for competitor (W,L,D per match)
        result_string_home (Union[Unset, str]): Result string for competitor at Home (W,L,D per match)
        result_string_away (Union[Unset, str]): Result string for competitor away (W,L,D per match)
    """

    played: Union[Unset, float] = UNSET
    played_home: Union[Unset, float] = UNSET
    played_away: Union[Unset, float] = UNSET
    washouts: Union[Unset, float] = UNSET
    wins: Union[Unset, float] = UNSET
    wins_home: Union[Unset, float] = UNSET
    wins_away: Union[Unset, float] = UNSET
    wins_secondary_score: Union[Unset, float] = UNSET
    wins_secondary_score_home: Union[Unset, float] = UNSET
    wins_secondary_score_away: Union[Unset, float] = UNSET
    losses: Union[Unset, float] = UNSET
    losses_home: Union[Unset, float] = UNSET
    losses_away: Union[Unset, float] = UNSET
    losses_secondary_score: Union[Unset, float] = UNSET
    losses_secondary_score_home: Union[Unset, float] = UNSET
    losses_secondary_score_away: Union[Unset, float] = UNSET
    draws: Union[Unset, float] = UNSET
    draws_home: Union[Unset, float] = UNSET
    draws_away: Union[Unset, float] = UNSET
    byes: Union[Unset, float] = UNSET
    forfeits_given: Union[Unset, float] = UNSET
    forfeits_won_by: Union[Unset, float] = UNSET
    win_percentage_display: Union[Unset, float] = UNSET
    win_percentage_home_display: Union[Unset, float] = UNSET
    win_percentage_away_display: Union[Unset, float] = UNSET
    win_percentage: Union[Unset, float] = UNSET
    win_percentage_home: Union[Unset, float] = UNSET
    win_percentage_away: Union[Unset, float] = UNSET
    scored_for: Union[Unset, float] = UNSET
    scored_for_home: Union[Unset, float] = UNSET
    scored_for_away: Union[Unset, float] = UNSET
    scored_for_average: Union[Unset, float] = UNSET
    scored_for_home_average: Union[Unset, float] = UNSET
    scored_for_away_average: Union[Unset, float] = UNSET
    scored_against: Union[Unset, float] = UNSET
    scored_against_home: Union[Unset, float] = UNSET
    scored_against_away: Union[Unset, float] = UNSET
    scored_against_average: Union[Unset, float] = UNSET
    scored_against_home_average: Union[Unset, float] = UNSET
    scored_against_away_average: Union[Unset, float] = UNSET
    percentage_display: Union[Unset, float] = UNSET
    percentage_home_display: Union[Unset, float] = UNSET
    percentage_away_display: Union[Unset, float] = UNSET
    percentage: Union[Unset, float] = UNSET
    percentage_home: Union[Unset, float] = UNSET
    percentage_away: Union[Unset, float] = UNSET
    point_difference: Union[Unset, float] = UNSET
    point_difference_home: Union[Unset, float] = UNSET
    point_difference_away: Union[Unset, float] = UNSET
    lowest_score_for: Union[None, Unset, float] = UNSET
    lowest_score_for_home: Union[None, Unset, float] = UNSET
    lowest_score_for_away: Union[None, Unset, float] = UNSET
    highest_score_for: Union[None, Unset, float] = UNSET
    highest_score_for_home: Union[None, Unset, float] = UNSET
    highest_score_for_away: Union[None, Unset, float] = UNSET
    lowest_score_against: Union[None, Unset, float] = UNSET
    lowest_score_against_home: Union[None, Unset, float] = UNSET
    lowest_score_against_away: Union[None, Unset, float] = UNSET
    highest_score_against: Union[None, Unset, float] = UNSET
    highest_score_against_home: Union[None, Unset, float] = UNSET
    highest_score_against_away: Union[None, Unset, float] = UNSET
    streak: Union[Unset, float] = UNSET
    streak_home: Union[Unset, float] = UNSET
    streak_away: Union[Unset, float] = UNSET
    result_string: Union[Unset, str] = UNSET
    result_string_home: Union[Unset, str] = UNSET
    result_string_away: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        played = self.played

        played_home = self.played_home

        played_away = self.played_away

        washouts = self.washouts

        wins = self.wins

        wins_home = self.wins_home

        wins_away = self.wins_away

        wins_secondary_score = self.wins_secondary_score

        wins_secondary_score_home = self.wins_secondary_score_home

        wins_secondary_score_away = self.wins_secondary_score_away

        losses = self.losses

        losses_home = self.losses_home

        losses_away = self.losses_away

        losses_secondary_score = self.losses_secondary_score

        losses_secondary_score_home = self.losses_secondary_score_home

        losses_secondary_score_away = self.losses_secondary_score_away

        draws = self.draws

        draws_home = self.draws_home

        draws_away = self.draws_away

        byes = self.byes

        forfeits_given = self.forfeits_given

        forfeits_won_by = self.forfeits_won_by

        win_percentage_display = self.win_percentage_display

        win_percentage_home_display = self.win_percentage_home_display

        win_percentage_away_display = self.win_percentage_away_display

        win_percentage = self.win_percentage

        win_percentage_home = self.win_percentage_home

        win_percentage_away = self.win_percentage_away

        scored_for = self.scored_for

        scored_for_home = self.scored_for_home

        scored_for_away = self.scored_for_away

        scored_for_average = self.scored_for_average

        scored_for_home_average = self.scored_for_home_average

        scored_for_away_average = self.scored_for_away_average

        scored_against = self.scored_against

        scored_against_home = self.scored_against_home

        scored_against_away = self.scored_against_away

        scored_against_average = self.scored_against_average

        scored_against_home_average = self.scored_against_home_average

        scored_against_away_average = self.scored_against_away_average

        percentage_display = self.percentage_display

        percentage_home_display = self.percentage_home_display

        percentage_away_display = self.percentage_away_display

        percentage = self.percentage

        percentage_home = self.percentage_home

        percentage_away = self.percentage_away

        point_difference = self.point_difference

        point_difference_home = self.point_difference_home

        point_difference_away = self.point_difference_away

        lowest_score_for: Union[None, Unset, float]
        if isinstance(self.lowest_score_for, Unset):
            lowest_score_for = UNSET
        else:
            lowest_score_for = self.lowest_score_for

        lowest_score_for_home: Union[None, Unset, float]
        if isinstance(self.lowest_score_for_home, Unset):
            lowest_score_for_home = UNSET
        else:
            lowest_score_for_home = self.lowest_score_for_home

        lowest_score_for_away: Union[None, Unset, float]
        if isinstance(self.lowest_score_for_away, Unset):
            lowest_score_for_away = UNSET
        else:
            lowest_score_for_away = self.lowest_score_for_away

        highest_score_for: Union[None, Unset, float]
        if isinstance(self.highest_score_for, Unset):
            highest_score_for = UNSET
        else:
            highest_score_for = self.highest_score_for

        highest_score_for_home: Union[None, Unset, float]
        if isinstance(self.highest_score_for_home, Unset):
            highest_score_for_home = UNSET
        else:
            highest_score_for_home = self.highest_score_for_home

        highest_score_for_away: Union[None, Unset, float]
        if isinstance(self.highest_score_for_away, Unset):
            highest_score_for_away = UNSET
        else:
            highest_score_for_away = self.highest_score_for_away

        lowest_score_against: Union[None, Unset, float]
        if isinstance(self.lowest_score_against, Unset):
            lowest_score_against = UNSET
        else:
            lowest_score_against = self.lowest_score_against

        lowest_score_against_home: Union[None, Unset, float]
        if isinstance(self.lowest_score_against_home, Unset):
            lowest_score_against_home = UNSET
        else:
            lowest_score_against_home = self.lowest_score_against_home

        lowest_score_against_away: Union[None, Unset, float]
        if isinstance(self.lowest_score_against_away, Unset):
            lowest_score_against_away = UNSET
        else:
            lowest_score_against_away = self.lowest_score_against_away

        highest_score_against: Union[None, Unset, float]
        if isinstance(self.highest_score_against, Unset):
            highest_score_against = UNSET
        else:
            highest_score_against = self.highest_score_against

        highest_score_against_home: Union[None, Unset, float]
        if isinstance(self.highest_score_against_home, Unset):
            highest_score_against_home = UNSET
        else:
            highest_score_against_home = self.highest_score_against_home

        highest_score_against_away: Union[None, Unset, float]
        if isinstance(self.highest_score_against_away, Unset):
            highest_score_against_away = UNSET
        else:
            highest_score_against_away = self.highest_score_against_away

        streak = self.streak

        streak_home = self.streak_home

        streak_away = self.streak_away

        result_string = self.result_string

        result_string_home = self.result_string_home

        result_string_away = self.result_string_away

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if played is not UNSET:
            field_dict["played"] = played
        if played_home is not UNSET:
            field_dict["playedHome"] = played_home
        if played_away is not UNSET:
            field_dict["playedAway"] = played_away
        if washouts is not UNSET:
            field_dict["washouts"] = washouts
        if wins is not UNSET:
            field_dict["wins"] = wins
        if wins_home is not UNSET:
            field_dict["winsHome"] = wins_home
        if wins_away is not UNSET:
            field_dict["winsAway"] = wins_away
        if wins_secondary_score is not UNSET:
            field_dict["winsSecondaryScore"] = wins_secondary_score
        if wins_secondary_score_home is not UNSET:
            field_dict["winsSecondaryScoreHome"] = wins_secondary_score_home
        if wins_secondary_score_away is not UNSET:
            field_dict["winsSecondaryScoreAway"] = wins_secondary_score_away
        if losses is not UNSET:
            field_dict["losses"] = losses
        if losses_home is not UNSET:
            field_dict["lossesHome"] = losses_home
        if losses_away is not UNSET:
            field_dict["lossesAway"] = losses_away
        if losses_secondary_score is not UNSET:
            field_dict["lossesSecondaryScore"] = losses_secondary_score
        if losses_secondary_score_home is not UNSET:
            field_dict["lossesSecondaryScoreHome"] = losses_secondary_score_home
        if losses_secondary_score_away is not UNSET:
            field_dict["lossesSecondaryScoreAway"] = losses_secondary_score_away
        if draws is not UNSET:
            field_dict["draws"] = draws
        if draws_home is not UNSET:
            field_dict["drawsHome"] = draws_home
        if draws_away is not UNSET:
            field_dict["drawsAway"] = draws_away
        if byes is not UNSET:
            field_dict["byes"] = byes
        if forfeits_given is not UNSET:
            field_dict["forfeitsGiven"] = forfeits_given
        if forfeits_won_by is not UNSET:
            field_dict["forfeitsWonBy"] = forfeits_won_by
        if win_percentage_display is not UNSET:
            field_dict["winPercentageDisplay"] = win_percentage_display
        if win_percentage_home_display is not UNSET:
            field_dict["winPercentageHomeDisplay"] = win_percentage_home_display
        if win_percentage_away_display is not UNSET:
            field_dict["winPercentageAwayDisplay"] = win_percentage_away_display
        if win_percentage is not UNSET:
            field_dict["winPercentage"] = win_percentage
        if win_percentage_home is not UNSET:
            field_dict["winPercentageHome"] = win_percentage_home
        if win_percentage_away is not UNSET:
            field_dict["winPercentageAway"] = win_percentage_away
        if scored_for is not UNSET:
            field_dict["scoredFor"] = scored_for
        if scored_for_home is not UNSET:
            field_dict["scoredForHome"] = scored_for_home
        if scored_for_away is not UNSET:
            field_dict["scoredForAway"] = scored_for_away
        if scored_for_average is not UNSET:
            field_dict["scoredForAverage"] = scored_for_average
        if scored_for_home_average is not UNSET:
            field_dict["scoredForHomeAverage"] = scored_for_home_average
        if scored_for_away_average is not UNSET:
            field_dict["scoredForAwayAverage"] = scored_for_away_average
        if scored_against is not UNSET:
            field_dict["scoredAgainst"] = scored_against
        if scored_against_home is not UNSET:
            field_dict["scoredAgainstHome"] = scored_against_home
        if scored_against_away is not UNSET:
            field_dict["scoredAgainstAway"] = scored_against_away
        if scored_against_average is not UNSET:
            field_dict["scoredAgainstAverage"] = scored_against_average
        if scored_against_home_average is not UNSET:
            field_dict["scoredAgainstHomeAverage"] = scored_against_home_average
        if scored_against_away_average is not UNSET:
            field_dict["scoredAgainstAwayAverage"] = scored_against_away_average
        if percentage_display is not UNSET:
            field_dict["percentageDisplay"] = percentage_display
        if percentage_home_display is not UNSET:
            field_dict["percentageHomeDisplay"] = percentage_home_display
        if percentage_away_display is not UNSET:
            field_dict["percentageAwayDisplay"] = percentage_away_display
        if percentage is not UNSET:
            field_dict["percentage"] = percentage
        if percentage_home is not UNSET:
            field_dict["percentageHome"] = percentage_home
        if percentage_away is not UNSET:
            field_dict["percentageAway"] = percentage_away
        if point_difference is not UNSET:
            field_dict["pointDifference"] = point_difference
        if point_difference_home is not UNSET:
            field_dict["pointDifferenceHome"] = point_difference_home
        if point_difference_away is not UNSET:
            field_dict["pointDifferenceAway"] = point_difference_away
        if lowest_score_for is not UNSET:
            field_dict["lowestScoreFor"] = lowest_score_for
        if lowest_score_for_home is not UNSET:
            field_dict["lowestScoreForHome"] = lowest_score_for_home
        if lowest_score_for_away is not UNSET:
            field_dict["lowestScoreForAway"] = lowest_score_for_away
        if highest_score_for is not UNSET:
            field_dict["highestScoreFor"] = highest_score_for
        if highest_score_for_home is not UNSET:
            field_dict["highestScoreForHome"] = highest_score_for_home
        if highest_score_for_away is not UNSET:
            field_dict["highestScoreForAway"] = highest_score_for_away
        if lowest_score_against is not UNSET:
            field_dict["lowestScoreAgainst"] = lowest_score_against
        if lowest_score_against_home is not UNSET:
            field_dict["lowestScoreAgainstHome"] = lowest_score_against_home
        if lowest_score_against_away is not UNSET:
            field_dict["lowestScoreAgainstAway"] = lowest_score_against_away
        if highest_score_against is not UNSET:
            field_dict["highestScoreAgainst"] = highest_score_against
        if highest_score_against_home is not UNSET:
            field_dict["highestScoreAgainstHome"] = highest_score_against_home
        if highest_score_against_away is not UNSET:
            field_dict["highestScoreAgainstAway"] = highest_score_against_away
        if streak is not UNSET:
            field_dict["streak"] = streak
        if streak_home is not UNSET:
            field_dict["streakHome"] = streak_home
        if streak_away is not UNSET:
            field_dict["streakAway"] = streak_away
        if result_string is not UNSET:
            field_dict["resultString"] = result_string
        if result_string_home is not UNSET:
            field_dict["resultStringHome"] = result_string_home
        if result_string_away is not UNSET:
            field_dict["resultStringAway"] = result_string_away

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        played = d.pop("played", UNSET)

        played_home = d.pop("playedHome", UNSET)

        played_away = d.pop("playedAway", UNSET)

        washouts = d.pop("washouts", UNSET)

        wins = d.pop("wins", UNSET)

        wins_home = d.pop("winsHome", UNSET)

        wins_away = d.pop("winsAway", UNSET)

        wins_secondary_score = d.pop("winsSecondaryScore", UNSET)

        wins_secondary_score_home = d.pop("winsSecondaryScoreHome", UNSET)

        wins_secondary_score_away = d.pop("winsSecondaryScoreAway", UNSET)

        losses = d.pop("losses", UNSET)

        losses_home = d.pop("lossesHome", UNSET)

        losses_away = d.pop("lossesAway", UNSET)

        losses_secondary_score = d.pop("lossesSecondaryScore", UNSET)

        losses_secondary_score_home = d.pop("lossesSecondaryScoreHome", UNSET)

        losses_secondary_score_away = d.pop("lossesSecondaryScoreAway", UNSET)

        draws = d.pop("draws", UNSET)

        draws_home = d.pop("drawsHome", UNSET)

        draws_away = d.pop("drawsAway", UNSET)

        byes = d.pop("byes", UNSET)

        forfeits_given = d.pop("forfeitsGiven", UNSET)

        forfeits_won_by = d.pop("forfeitsWonBy", UNSET)

        win_percentage_display = d.pop("winPercentageDisplay", UNSET)

        win_percentage_home_display = d.pop("winPercentageHomeDisplay", UNSET)

        win_percentage_away_display = d.pop("winPercentageAwayDisplay", UNSET)

        win_percentage = d.pop("winPercentage", UNSET)

        win_percentage_home = d.pop("winPercentageHome", UNSET)

        win_percentage_away = d.pop("winPercentageAway", UNSET)

        scored_for = d.pop("scoredFor", UNSET)

        scored_for_home = d.pop("scoredForHome", UNSET)

        scored_for_away = d.pop("scoredForAway", UNSET)

        scored_for_average = d.pop("scoredForAverage", UNSET)

        scored_for_home_average = d.pop("scoredForHomeAverage", UNSET)

        scored_for_away_average = d.pop("scoredForAwayAverage", UNSET)

        scored_against = d.pop("scoredAgainst", UNSET)

        scored_against_home = d.pop("scoredAgainstHome", UNSET)

        scored_against_away = d.pop("scoredAgainstAway", UNSET)

        scored_against_average = d.pop("scoredAgainstAverage", UNSET)

        scored_against_home_average = d.pop("scoredAgainstHomeAverage", UNSET)

        scored_against_away_average = d.pop("scoredAgainstAwayAverage", UNSET)

        percentage_display = d.pop("percentageDisplay", UNSET)

        percentage_home_display = d.pop("percentageHomeDisplay", UNSET)

        percentage_away_display = d.pop("percentageAwayDisplay", UNSET)

        percentage = d.pop("percentage", UNSET)

        percentage_home = d.pop("percentageHome", UNSET)

        percentage_away = d.pop("percentageAway", UNSET)

        point_difference = d.pop("pointDifference", UNSET)

        point_difference_home = d.pop("pointDifferenceHome", UNSET)

        point_difference_away = d.pop("pointDifferenceAway", UNSET)

        def _parse_lowest_score_for(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lowest_score_for = _parse_lowest_score_for(d.pop("lowestScoreFor", UNSET))

        def _parse_lowest_score_for_home(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lowest_score_for_home = _parse_lowest_score_for_home(d.pop("lowestScoreForHome", UNSET))

        def _parse_lowest_score_for_away(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lowest_score_for_away = _parse_lowest_score_for_away(d.pop("lowestScoreForAway", UNSET))

        def _parse_highest_score_for(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        highest_score_for = _parse_highest_score_for(d.pop("highestScoreFor", UNSET))

        def _parse_highest_score_for_home(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        highest_score_for_home = _parse_highest_score_for_home(d.pop("highestScoreForHome", UNSET))

        def _parse_highest_score_for_away(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        highest_score_for_away = _parse_highest_score_for_away(d.pop("highestScoreForAway", UNSET))

        def _parse_lowest_score_against(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lowest_score_against = _parse_lowest_score_against(d.pop("lowestScoreAgainst", UNSET))

        def _parse_lowest_score_against_home(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lowest_score_against_home = _parse_lowest_score_against_home(d.pop("lowestScoreAgainstHome", UNSET))

        def _parse_lowest_score_against_away(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lowest_score_against_away = _parse_lowest_score_against_away(d.pop("lowestScoreAgainstAway", UNSET))

        def _parse_highest_score_against(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        highest_score_against = _parse_highest_score_against(d.pop("highestScoreAgainst", UNSET))

        def _parse_highest_score_against_home(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        highest_score_against_home = _parse_highest_score_against_home(d.pop("highestScoreAgainstHome", UNSET))

        def _parse_highest_score_against_away(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        highest_score_against_away = _parse_highest_score_against_away(d.pop("highestScoreAgainstAway", UNSET))

        streak = d.pop("streak", UNSET)

        streak_home = d.pop("streakHome", UNSET)

        streak_away = d.pop("streakAway", UNSET)

        result_string = d.pop("resultString", UNSET)

        result_string_home = d.pop("resultStringHome", UNSET)

        result_string_away = d.pop("resultStringAway", UNSET)

        standing_model_calculated_additional_property = cls(
            played=played,
            played_home=played_home,
            played_away=played_away,
            washouts=washouts,
            wins=wins,
            wins_home=wins_home,
            wins_away=wins_away,
            wins_secondary_score=wins_secondary_score,
            wins_secondary_score_home=wins_secondary_score_home,
            wins_secondary_score_away=wins_secondary_score_away,
            losses=losses,
            losses_home=losses_home,
            losses_away=losses_away,
            losses_secondary_score=losses_secondary_score,
            losses_secondary_score_home=losses_secondary_score_home,
            losses_secondary_score_away=losses_secondary_score_away,
            draws=draws,
            draws_home=draws_home,
            draws_away=draws_away,
            byes=byes,
            forfeits_given=forfeits_given,
            forfeits_won_by=forfeits_won_by,
            win_percentage_display=win_percentage_display,
            win_percentage_home_display=win_percentage_home_display,
            win_percentage_away_display=win_percentage_away_display,
            win_percentage=win_percentage,
            win_percentage_home=win_percentage_home,
            win_percentage_away=win_percentage_away,
            scored_for=scored_for,
            scored_for_home=scored_for_home,
            scored_for_away=scored_for_away,
            scored_for_average=scored_for_average,
            scored_for_home_average=scored_for_home_average,
            scored_for_away_average=scored_for_away_average,
            scored_against=scored_against,
            scored_against_home=scored_against_home,
            scored_against_away=scored_against_away,
            scored_against_average=scored_against_average,
            scored_against_home_average=scored_against_home_average,
            scored_against_away_average=scored_against_away_average,
            percentage_display=percentage_display,
            percentage_home_display=percentage_home_display,
            percentage_away_display=percentage_away_display,
            percentage=percentage,
            percentage_home=percentage_home,
            percentage_away=percentage_away,
            point_difference=point_difference,
            point_difference_home=point_difference_home,
            point_difference_away=point_difference_away,
            lowest_score_for=lowest_score_for,
            lowest_score_for_home=lowest_score_for_home,
            lowest_score_for_away=lowest_score_for_away,
            highest_score_for=highest_score_for,
            highest_score_for_home=highest_score_for_home,
            highest_score_for_away=highest_score_for_away,
            lowest_score_against=lowest_score_against,
            lowest_score_against_home=lowest_score_against_home,
            lowest_score_against_away=lowest_score_against_away,
            highest_score_against=highest_score_against,
            highest_score_against_home=highest_score_against_home,
            highest_score_against_away=highest_score_against_away,
            streak=streak,
            streak_home=streak_home,
            streak_away=streak_away,
            result_string=result_string,
            result_string_home=result_string_home,
            result_string_away=result_string_away,
        )

        return standing_model_calculated_additional_property



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="TeamModelEntityAdditionalDetails")


@_attrs_define
class TeamModelEntityAdditionalDetails:
    """Additional detail fields

    Attributes:
        founded (Union[None, Unset, float]): Year Founded
        squad_value (Union[None, Unset, float]): Value of Squad
    """

    founded: Union[None, Unset, float] = UNSET
    squad_value: Union[None, Unset, float] = UNSET

    def to_dict(self) -> dict[str, Any]:
        founded: Union[None, Unset, float]
        if isinstance(self.founded, Unset):
            founded = UNSET
        else:
            founded = self.founded

        squad_value: Union[None, Unset, float]
        if isinstance(self.squad_value, Unset):
            squad_value = UNSET
        else:
            squad_value = self.squad_value

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if founded is not UNSET:
            field_dict["founded"] = founded
        if squad_value is not UNSET:
            field_dict["squadValue"] = squad_value

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_founded(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        founded = _parse_founded(d.pop("founded", UNSET))

        def _parse_squad_value(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        squad_value = _parse_squad_value(d.pop("squadValue", UNSET))

        team_model_entity_additional_details = cls(
            founded=founded,
            squad_value=squad_value,
        )

        return team_model_entity_additional_details



from enum import Enum


class ChangeLogModelChangeType(str, Enum):
    DELETE = "delete"
    FIXTURE_CHANGE = "fixture_change"
    FIXTURE_RESET = "fixture_reset"
    FIXTURE_VIDEOSTREAM_DISABLE = "fixture_videostream_disable"
    FIXTURE_VIDEOSTREAM_ENABLE = "fixture_videostream_enable"
    MOVE = "move"
    POST = "post"
    PUT = "put"
    UPDATE = "update"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.competition_model_age_group_type_1 import CompetitionModelAgeGroupType1
from ..models.competition_model_age_group_type_2_type_1 import CompetitionModelAgeGroupType2Type1
from ..models.competition_model_age_group_type_3_type_1 import CompetitionModelAgeGroupType3Type1
from ..models.competition_model_event_type import CompetitionModelEventType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.competition_model_competition_historical_name import CompetitionModelCompetitionHistoricalName
    from ..models.competition_model_league import CompetitionModelLeague
    from ..models.competition_model_organization import CompetitionModelOrganization
    from ..models.competition_model_social_media import CompetitionModelSocialMedia
    from ..models.images_model import ImagesModel


T = TypeVar("T", bound="CompetitionModel")


@_attrs_define
class CompetitionModel:
    """
    Attributes:
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, CompetitionModelOrganization]): The organization that this competition belongs to
        league_id (Union[Unset, UUID]): The unique identifier of the league Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        league (Union[Unset, CompetitionModelLeague]): The league that this competition belongs to
        international_reference (Union[None, Unset, str]): The international reference for this competition given by the
            sport governing body Example: CA3243-3.
        abbreviation_local (Union[None, Unset, str]): An abbreviation/short name in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: NFA.
        name_local (Union[Unset, str]): The name of the competition in the [local](#section/Introduction/Character-Sets-
            and-Names) language Example: Test name local.
        event_type (Union[Unset, CompetitionModelEventType]): Primary Type of Matches
            >- `FIXTURE` Fixture
            >- `PRACTICE` Practice
             Default: CompetitionModelEventType.FIXTURE. Example: FIXTURE.
        abbreviation_latin (Union[None, Unset, str]): An abbreviation/short name in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: NFA.
        name_latin (Union[None, Unset, str]): The name of the competition in [latin](#section/Introduction/Character-
            Sets-and-Names) characters Example: Test name latin .
        social (Union['CompetitionModelSocialMedia', None, Unset]): Social Media contacts
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        historical_names (Union[None, Unset, list['CompetitionModelCompetitionHistoricalName']]): Array of competition
            historical names
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        age_group (Union[CompetitionModelAgeGroupType1, CompetitionModelAgeGroupType2Type1,
            CompetitionModelAgeGroupType3Type1, None, Unset]): The age group of the competition
            >- None None
            >- `JUNIOR` Junior
            >- `MASTERS` Masters
            >- `SENIOR` Senior
            >- `UNDER_15` Under 15
            >- `UNDER_16` Under 16
            >- `UNDER_17` Under 17
            >- `UNDER_18` Under 18
            >- `UNDER_19` Under 19
            >- `UNDER_20` Under 20
            >- `UNDER_21` Under 21
            >- `UNDER_22` Under 22
            >- `UNDER_23` Under 23
            >- `YOUTH` Youth
             Example: SENIOR.
        images (Union[Unset, list['ImagesModel']]):
    """

    competition_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "CompetitionModelOrganization"] = UNSET
    league_id: Union[Unset, UUID] = UNSET
    league: Union[Unset, "CompetitionModelLeague"] = UNSET
    international_reference: Union[None, Unset, str] = UNSET
    abbreviation_local: Union[None, Unset, str] = UNSET
    name_local: Union[Unset, str] = UNSET
    event_type: Union[Unset, CompetitionModelEventType] = CompetitionModelEventType.FIXTURE
    abbreviation_latin: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    social: Union["CompetitionModelSocialMedia", None, Unset] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    historical_names: Union[None, Unset, list["CompetitionModelCompetitionHistoricalName"]] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    age_group: Union[
        CompetitionModelAgeGroupType1,
        CompetitionModelAgeGroupType2Type1,
        CompetitionModelAgeGroupType3Type1,
        None,
        Unset,
    ] = UNSET
    images: Union[Unset, list["ImagesModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.competition_model_social_media import CompetitionModelSocialMedia

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        league_id: Union[Unset, str] = UNSET
        if not isinstance(self.league_id, Unset):
            league_id = str(self.league_id)

        league: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.league, Unset):
            league = self.league.to_dict()

        international_reference: Union[None, Unset, str]
        if isinstance(self.international_reference, Unset):
            international_reference = UNSET
        else:
            international_reference = self.international_reference

        abbreviation_local: Union[None, Unset, str]
        if isinstance(self.abbreviation_local, Unset):
            abbreviation_local = UNSET
        else:
            abbreviation_local = self.abbreviation_local

        name_local = self.name_local

        event_type: Union[Unset, str] = UNSET
        if not isinstance(self.event_type, Unset):
            event_type = self.event_type.value

        abbreviation_latin: Union[None, Unset, str]
        if isinstance(self.abbreviation_latin, Unset):
            abbreviation_latin = UNSET
        else:
            abbreviation_latin = self.abbreviation_latin

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        social: Union[None, Unset, dict[str, Any]]
        if isinstance(self.social, Unset):
            social = UNSET
        elif isinstance(self.social, CompetitionModelSocialMedia):
            social = self.social.to_dict()
        else:
            social = self.social

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        historical_names: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.historical_names, Unset):
            historical_names = UNSET
        elif isinstance(self.historical_names, list):
            historical_names = []
            for historical_names_type_0_item_data in self.historical_names:
                historical_names_type_0_item = historical_names_type_0_item_data.to_dict()
                historical_names.append(historical_names_type_0_item)

        else:
            historical_names = self.historical_names

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        age_group: Union[None, Unset, str]
        if isinstance(self.age_group, Unset):
            age_group = UNSET
        elif isinstance(self.age_group, CompetitionModelAgeGroupType1):
            age_group = self.age_group.value
        elif isinstance(self.age_group, CompetitionModelAgeGroupType2Type1):
            age_group = self.age_group.value
        elif isinstance(self.age_group, CompetitionModelAgeGroupType3Type1):
            age_group = self.age_group.value
        else:
            age_group = self.age_group

        images: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            images = []
            for images_item_data in self.images:
                images_item = images_item_data.to_dict()
                images.append(images_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if league_id is not UNSET:
            field_dict["leagueId"] = league_id
        if league is not UNSET:
            field_dict["league"] = league
        if international_reference is not UNSET:
            field_dict["internationalReference"] = international_reference
        if abbreviation_local is not UNSET:
            field_dict["abbreviationLocal"] = abbreviation_local
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if event_type is not UNSET:
            field_dict["eventType"] = event_type
        if abbreviation_latin is not UNSET:
            field_dict["abbreviationLatin"] = abbreviation_latin
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if social is not UNSET:
            field_dict["social"] = social
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if historical_names is not UNSET:
            field_dict["historicalNames"] = historical_names
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if age_group is not UNSET:
            field_dict["ageGroup"] = age_group
        if images is not UNSET:
            field_dict["images"] = images

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.competition_model_competition_historical_name import CompetitionModelCompetitionHistoricalName
        from ..models.competition_model_league import CompetitionModelLeague
        from ..models.competition_model_organization import CompetitionModelOrganization
        from ..models.competition_model_social_media import CompetitionModelSocialMedia
        from ..models.images_model import ImagesModel

        d = dict(src_dict)
        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, CompetitionModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = CompetitionModelOrganization.from_dict(_organization)

        _league_id = d.pop("leagueId", UNSET)
        league_id: Union[Unset, UUID]
        if isinstance(_league_id, Unset):
            league_id = UNSET
        else:
            league_id = UUID(_league_id)

        _league = d.pop("league", UNSET)
        league: Union[Unset, CompetitionModelLeague]
        if isinstance(_league, Unset):
            league = UNSET
        else:
            league = CompetitionModelLeague.from_dict(_league)

        def _parse_international_reference(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        international_reference = _parse_international_reference(d.pop("internationalReference", UNSET))

        def _parse_abbreviation_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_local = _parse_abbreviation_local(d.pop("abbreviationLocal", UNSET))

        name_local = d.pop("nameLocal", UNSET)

        _event_type = d.pop("eventType", UNSET)
        event_type: Union[Unset, CompetitionModelEventType]
        if isinstance(_event_type, Unset):
            event_type = UNSET
        else:
            event_type = CompetitionModelEventType(_event_type)

        def _parse_abbreviation_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_latin = _parse_abbreviation_latin(d.pop("abbreviationLatin", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_social(data: object) -> Union["CompetitionModelSocialMedia", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                social_type_0 = CompetitionModelSocialMedia.from_dict(data)

                return social_type_0
            except:  # noqa: E722
                pass
            return cast(Union["CompetitionModelSocialMedia", None, Unset], data)

        social = _parse_social(d.pop("social", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        def _parse_historical_names(
            data: object,
        ) -> Union[None, Unset, list["CompetitionModelCompetitionHistoricalName"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                historical_names_type_0 = []
                _historical_names_type_0 = data
                for historical_names_type_0_item_data in _historical_names_type_0:
                    historical_names_type_0_item = CompetitionModelCompetitionHistoricalName.from_dict(
                        historical_names_type_0_item_data
                    )

                    historical_names_type_0.append(historical_names_type_0_item)

                return historical_names_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["CompetitionModelCompetitionHistoricalName"]], data)

        historical_names = _parse_historical_names(d.pop("historicalNames", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        def _parse_age_group(
            data: object,
        ) -> Union[
            CompetitionModelAgeGroupType1,
            CompetitionModelAgeGroupType2Type1,
            CompetitionModelAgeGroupType3Type1,
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                age_group_type_1 = CompetitionModelAgeGroupType1(data)

                return age_group_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                age_group_type_2_type_1 = CompetitionModelAgeGroupType2Type1(data)

                return age_group_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                age_group_type_3_type_1 = CompetitionModelAgeGroupType3Type1(data)

                return age_group_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    CompetitionModelAgeGroupType1,
                    CompetitionModelAgeGroupType2Type1,
                    CompetitionModelAgeGroupType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        age_group = _parse_age_group(d.pop("ageGroup", UNSET))

        images = []
        _images = d.pop("images", UNSET)
        for images_item_data in _images or []:
            images_item = ImagesModel.from_dict(images_item_data)

            images.append(images_item)

        competition_model = cls(
            competition_id=competition_id,
            organization_id=organization_id,
            organization=organization,
            league_id=league_id,
            league=league,
            international_reference=international_reference,
            abbreviation_local=abbreviation_local,
            name_local=name_local,
            event_type=event_type,
            abbreviation_latin=abbreviation_latin,
            name_latin=name_latin,
            social=social,
            external_id=external_id,
            historical_names=historical_names,
            updated=updated,
            added=added,
            age_group=age_group,
            images=images,
        )

        return competition_model



from enum import Enum


class UniformItemsBySeasonListItemType(str, Enum):
    BOTTOM = "BOTTOM"
    GOALKEEPER_BOTTOM = "GOALKEEPER_BOTTOM"
    GOALKEEPER_TOP = "GOALKEEPER_TOP"
    HELMET = "HELMET"
    SOCKS = "SOCKS"
    TOP = "TOP"
    WARMUP_BOTTOM = "WARMUP_BOTTOM"
    WARMUP_TOP = "WARMUP_TOP"

    def __str__(self) -> str:
        return str(self.value)



"""Sportradar DataCore API Client
Handles authentication, token management, and API requests.
Provides methods to access various endpoints.

Author: Michael Adams, 2025
"""

import logging
import time
from threading import RLock
from types import TracebackType
from typing import Any, TypeVar
from uuid import UUID

import httpx
from datacore_client import AuthenticatedClient
from datacore_client.types import UNSET, Unset

from sportradar_datacore_api.errors import (
    AuthenticationError,
    NotFoundError,
    TransportError,
    UnexpectedResponseError,
    ValidationError,
)

logger = logging.getLogger(__name__)

T = TypeVar("T")


class DataCoreAPI:
    """
    OAuth2-authenticated wrapper for Sportradar DataCore.
    Handles token acquisition, caching, and renewal.
    """

    _TOKEN_BUFFER = 60  # seconds before actual expiry to refresh

    def __init__(  # noqa: PLR0913
        self,
        base_url: str,
        auth_url: str,
        client_id: str,
        client_secret: str,
        sport: str,
        org_id: str | None = None,
        scopes: list[str] | None = None,
        timeout: int = 5,
        connect_on_init: bool = True,
    ) -> None:
        self.base_url = base_url.rstrip("/")
        self.auth_url = auth_url
        self.client_id = client_id
        self.client_secret = client_secret
        self.sport = sport
        self.org_id = org_id
        self.scopes: list[str] = scopes or ["read:organization"]
        self.timeout = timeout

        self._token: str | None = None
        self._expires_at: float = 0.0
        self._lock = RLock()

        self.client: AuthenticatedClient | None = None

        self.session = httpx.Client()
        self.session.headers.update(
            {
                "Accept": "application/json",
                "Content-Type": "application/json",
            }
        )
        if connect_on_init:
            self.connect()

    def connect(
        self,
    ) -> None:
        self._ensure_client()

    def _authenticate(self) -> None:
        payload: dict[str, Any] = {
            "credentialId": self.client_id,
            "credentialSecret": self.client_secret,
            "sport": self.sport,
            "organization": {"id": [self.org_id]} if self.org_id else None,
            "scopes": self.scopes,
        }
        payload = {k: v for k, v in payload.items() if v is not None}

        try:
            response = self.session.post(
                self.auth_url, json=payload, timeout=self.timeout
            )
            response.raise_for_status()
        except httpx.HTTPError as e:
            raise TransportError(f"Authentication failed: {e}") from e

        data = response.json().get("data", {})
        self._token = data.get("token")
        if not self._token:
            raise AuthenticationError("Token missing in authentication response.")

        logger.debug("Authenticated successfully")

        expires_in = data.get("expires_in", 3600)
        self._expires_at = time.time() + expires_in - self._TOKEN_BUFFER
        self.session.headers.update({"Authorization": f"Bearer {self._token}"})

        if self.client is not None:
            self.client.token = self._token

    def _ensure_token(self) -> None:
        with self._lock:
            if not self._token or time.time() >= self._expires_at:
                logger.info("Refreshing access token")
                self._authenticate()

    def _ensure_client(self) -> AuthenticatedClient:
        with self._lock:
            self._ensure_token()
            if self._token is None:
                raise AuthenticationError("Authentication token was not initialized.")
            token = self._token
            if self.client is None:
                self.client = AuthenticatedClient(
                    base_url=self.base_url,
                    token=token,
                    verify_ssl=True,  # enforce SSL in production
                    raise_on_unexpected_status=True,
                    timeout=httpx.Timeout(self.timeout),
                )
            else:
                self.client.token = token
            return self.client

    @staticmethod
    def _require_value(name: str, value: str) -> None:
        if not value:
            raise ValidationError(f"{name} must be provided.")

    @staticmethod
    def _as_uuid(value: str | UUID, name: str) -> UUID:
        if isinstance(value, UUID):
            return value
        try:
            return UUID(str(value))
        except ValueError as exc:
            raise ValidationError(f"{name} must be a valid UUID.") from exc

    @staticmethod
    def _as_offset(offset: int | None) -> int | Unset:
        return UNSET if offset is None else offset

    @staticmethod
    def _uuid_to_str(value: UUID | Unset | None, name: str) -> str:
        if value is None or isinstance(value, Unset):
            raise NotFoundError(f"{name} is missing in response.")
        return str(value)

    def _unwrap_response(self, parsed: Any, success_type: type[T], context: str) -> T:
        if parsed is None:
            raise UnexpectedResponseError(f"{context}: empty response")
        if isinstance(parsed, success_type):
            return parsed
        raise UnexpectedResponseError(f"{context}: API error: {parsed}")

    def close(self) -> None:
        self.session.close()

    def __enter__(self) -> "DataCoreAPI":
        self._ensure_client()
        return self

    def __exit__(
        self,
        exc_type: type[BaseException] | None,
        exc: BaseException | None,
        traceback: TracebackType | None,
    ) -> None:
        self.close()



from enum import Enum


class SeasonModelPromotionRelegationRulesType0ItemRuleType(str, Enum):
    PROMOTION = "PROMOTION"
    RELEGATION = "RELEGATION"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="TransferModelTransferComponent")


@_attrs_define
class TransferModelTransferComponent:
    """
    Attributes:
        person_id (Union[Unset, str]): The uuid of the person
        from_entity_group_id (Union[Unset, str]): The uuid of the source entity group
        to_entity_group_id (Union[Unset, str]): The uuid of the destination entity group
        extra_allowances (Union[Unset, str]): Details of additional allowances included in the transfer Example: Cash,
            1st Round Pick.
    """

    person_id: Union[Unset, str] = UNSET
    from_entity_group_id: Union[Unset, str] = UNSET
    to_entity_group_id: Union[Unset, str] = UNSET
    extra_allowances: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        person_id = self.person_id

        from_entity_group_id = self.from_entity_group_id

        to_entity_group_id = self.to_entity_group_id

        extra_allowances = self.extra_allowances

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if from_entity_group_id is not UNSET:
            field_dict["fromEntityGroupId"] = from_entity_group_id
        if to_entity_group_id is not UNSET:
            field_dict["toEntityGroupId"] = to_entity_group_id
        if extra_allowances is not UNSET:
            field_dict["extraAllowances"] = extra_allowances

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        person_id = d.pop("personId", UNSET)

        from_entity_group_id = d.pop("fromEntityGroupId", UNSET)

        to_entity_group_id = d.pop("toEntityGroupId", UNSET)

        extra_allowances = d.pop("extraAllowances", UNSET)

        transfer_model_transfer_component = cls(
            person_id=person_id,
            from_entity_group_id=from_entity_group_id,
            to_entity_group_id=to_entity_group_id,
            extra_allowances=extra_allowances,
        )

        return transfer_model_transfer_component



from enum import Enum


class VideoSubscriptionModelOutputFormat(str, Enum):
    HLS = "HLS"
    RTMP = "RTMP"
    RTMP_PULL = "RTMP_PULL"
    SRT = "SRT"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="TeamModelTeamHistoricalName")


@_attrs_define
class TeamModelTeamHistoricalName:
    """
    Attributes:
        date_start (Union[None, Unset, datetime.date]): Start date
        date_end (Union[None, Unset, datetime.date]): End date
        name_full_local (Union[None, Unset, str]): Full name in local language
        name_full_latin (Union[None, Unset, str]): Full name in latin characters
        name_short_local (Union[None, Unset, str]): Short name in local language
        name_short_latin (Union[None, Unset, str]): Short name in latin characters
        name_place_local (Union[None, Unset, str]): Place name in latin characters
    """

    date_start: Union[None, Unset, datetime.date] = UNSET
    date_end: Union[None, Unset, datetime.date] = UNSET
    name_full_local: Union[None, Unset, str] = UNSET
    name_full_latin: Union[None, Unset, str] = UNSET
    name_short_local: Union[None, Unset, str] = UNSET
    name_short_latin: Union[None, Unset, str] = UNSET
    name_place_local: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        date_start: Union[None, Unset, str]
        if isinstance(self.date_start, Unset):
            date_start = UNSET
        elif isinstance(self.date_start, datetime.date):
            date_start = self.date_start.isoformat()
        else:
            date_start = self.date_start

        date_end: Union[None, Unset, str]
        if isinstance(self.date_end, Unset):
            date_end = UNSET
        elif isinstance(self.date_end, datetime.date):
            date_end = self.date_end.isoformat()
        else:
            date_end = self.date_end

        name_full_local: Union[None, Unset, str]
        if isinstance(self.name_full_local, Unset):
            name_full_local = UNSET
        else:
            name_full_local = self.name_full_local

        name_full_latin: Union[None, Unset, str]
        if isinstance(self.name_full_latin, Unset):
            name_full_latin = UNSET
        else:
            name_full_latin = self.name_full_latin

        name_short_local: Union[None, Unset, str]
        if isinstance(self.name_short_local, Unset):
            name_short_local = UNSET
        else:
            name_short_local = self.name_short_local

        name_short_latin: Union[None, Unset, str]
        if isinstance(self.name_short_latin, Unset):
            name_short_latin = UNSET
        else:
            name_short_latin = self.name_short_latin

        name_place_local: Union[None, Unset, str]
        if isinstance(self.name_place_local, Unset):
            name_place_local = UNSET
        else:
            name_place_local = self.name_place_local

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if date_start is not UNSET:
            field_dict["dateStart"] = date_start
        if date_end is not UNSET:
            field_dict["dateEnd"] = date_end
        if name_full_local is not UNSET:
            field_dict["nameFullLocal"] = name_full_local
        if name_full_latin is not UNSET:
            field_dict["nameFullLatin"] = name_full_latin
        if name_short_local is not UNSET:
            field_dict["nameShortLocal"] = name_short_local
        if name_short_latin is not UNSET:
            field_dict["nameShortLatin"] = name_short_latin
        if name_place_local is not UNSET:
            field_dict["namePlaceLocal"] = name_place_local

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_date_start(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_start_type_0 = isoparse(data).date()

                return date_start_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_start = _parse_date_start(d.pop("dateStart", UNSET))

        def _parse_date_end(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_end_type_0 = isoparse(data).date()

                return date_end_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_end = _parse_date_end(d.pop("dateEnd", UNSET))

        def _parse_name_full_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_full_local = _parse_name_full_local(d.pop("nameFullLocal", UNSET))

        def _parse_name_full_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_full_latin = _parse_name_full_latin(d.pop("nameFullLatin", UNSET))

        def _parse_name_short_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_short_local = _parse_name_short_local(d.pop("nameShortLocal", UNSET))

        def _parse_name_short_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_short_latin = _parse_name_short_latin(d.pop("nameShortLatin", UNSET))

        def _parse_name_place_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_place_local = _parse_name_place_local(d.pop("namePlaceLocal", UNSET))

        team_model_team_historical_name = cls(
            date_start=date_start,
            date_end=date_end,
            name_full_local=name_full_local,
            name_full_latin=name_full_latin,
            name_short_local=name_short_local,
            name_short_latin=name_short_latin,
            name_place_local=name_place_local,
        )

        return team_model_team_historical_name



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.person_model_gender import PersonModelGender
from ..models.person_model_status import PersonModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.images_model import ImagesModel
    from ..models.person_model_additional_names_type_0 import PersonModelAdditionalNamesType0
    from ..models.person_model_organization import PersonModelOrganization
    from ..models.person_model_person_additional_details import PersonModelPersonAdditionalDetails
    from ..models.person_model_person_historical_name import PersonModelPersonHistoricalName
    from ..models.person_model_social_media import PersonModelSocialMedia


T = TypeVar("T", bound="PersonModel")


@_attrs_define
class PersonModel:
    """
    Attributes:
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, PersonModelOrganization]): The organization that this person belongs to
        status (Union[Unset, PersonModelStatus]): Status
            >- `ACTIVE` Active
            >- `DECEASED` Deceased
            >- `INACTIVE` Inactive
            >- `PENDING` Pending
            >- `UNREGISTERED` UnRegistered
             Default: PersonModelStatus.ACTIVE. Example: ACTIVE.
        gender (Union[Unset, PersonModelGender]): The gender of the person
            >- `FEMALE` Female
            >- `MALE` Male
            >- `UNKNOWN` Unknown
             Example: MALE.
        name_full_local (Union[Unset, str]): The full name of the person in [local](#section/Introduction/Character-
            Sets-and-Names) language Example: John Smith.
        name_abbreviated (Union[None, Unset, str]): An abbreviated name for a person Example: Pat.
        language_local (Union[None, Unset, str]): The language code of the full name in
            [local](#section/Introduction/Character-Sets-and-Names) language. This code is a two letter (lower-case) ISO
            639-1 language code. Example: en.
        name_given_local (Union[None, Unset, str]): Given name of the person in [local](#section/Introduction/Character-
            Sets-and-Names) language Example: John.
        name_family_local (Union[None, Unset, str]): Family name of the person in
            [local](#section/Introduction/Character-Sets-and-Names) language Example: Smith.
        name_full_latin (Union[None, Unset, str]): The full name of the person in
            [latin](##section/Introduction/Character-Sets-and-Names) characters Example: John Smith.
        name_given_latin (Union[None, Unset, str]): Given name of the person in [latin](#section/Introduction/Character-
            Sets-and-Names) characters Example: John.
        name_family_latin (Union[None, Unset, str]): Family name of the person in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: Smith.
        dob (Union[None, Unset, datetime.date]): Date of Birth Example: 1978-08-24.
        nationality (Union[None, Unset, str]): A 3 letter nationality code. We recommend you use ISO-3166 where
            available. Example: AUS.
        deceased (Union[None, Unset, datetime.date]): Date deceased Example: 2016-09-08.
        additional_names (Union['PersonModelAdditionalNamesType0', None, Unset]): Additional names for the person. They
            are broken down by language, so you can have a different set of names per language
        additional_details (Union['PersonModelPersonAdditionalDetails', None, Unset]): Additional person detail fields
        social (Union['PersonModelSocialMedia', None, Unset]): Social Media contacts
        historical_names (Union[None, Unset, list['PersonModelPersonHistoricalName']]): Array of person historical names
        representing (Union[None, Unset, str]): Who the person or team was representing Example: AUSTRALIA.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        images (Union[Unset, list['ImagesModel']]):
    """

    person_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "PersonModelOrganization"] = UNSET
    status: Union[Unset, PersonModelStatus] = PersonModelStatus.ACTIVE
    gender: Union[Unset, PersonModelGender] = UNSET
    name_full_local: Union[Unset, str] = UNSET
    name_abbreviated: Union[None, Unset, str] = UNSET
    language_local: Union[None, Unset, str] = UNSET
    name_given_local: Union[None, Unset, str] = UNSET
    name_family_local: Union[None, Unset, str] = UNSET
    name_full_latin: Union[None, Unset, str] = UNSET
    name_given_latin: Union[None, Unset, str] = UNSET
    name_family_latin: Union[None, Unset, str] = UNSET
    dob: Union[None, Unset, datetime.date] = UNSET
    nationality: Union[None, Unset, str] = UNSET
    deceased: Union[None, Unset, datetime.date] = UNSET
    additional_names: Union["PersonModelAdditionalNamesType0", None, Unset] = UNSET
    additional_details: Union["PersonModelPersonAdditionalDetails", None, Unset] = UNSET
    social: Union["PersonModelSocialMedia", None, Unset] = UNSET
    historical_names: Union[None, Unset, list["PersonModelPersonHistoricalName"]] = UNSET
    representing: Union[None, Unset, str] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    images: Union[Unset, list["ImagesModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.person_model_additional_names_type_0 import PersonModelAdditionalNamesType0
        from ..models.person_model_person_additional_details import PersonModelPersonAdditionalDetails
        from ..models.person_model_social_media import PersonModelSocialMedia

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        gender: Union[Unset, str] = UNSET
        if not isinstance(self.gender, Unset):
            gender = self.gender.value

        name_full_local = self.name_full_local

        name_abbreviated: Union[None, Unset, str]
        if isinstance(self.name_abbreviated, Unset):
            name_abbreviated = UNSET
        else:
            name_abbreviated = self.name_abbreviated

        language_local: Union[None, Unset, str]
        if isinstance(self.language_local, Unset):
            language_local = UNSET
        else:
            language_local = self.language_local

        name_given_local: Union[None, Unset, str]
        if isinstance(self.name_given_local, Unset):
            name_given_local = UNSET
        else:
            name_given_local = self.name_given_local

        name_family_local: Union[None, Unset, str]
        if isinstance(self.name_family_local, Unset):
            name_family_local = UNSET
        else:
            name_family_local = self.name_family_local

        name_full_latin: Union[None, Unset, str]
        if isinstance(self.name_full_latin, Unset):
            name_full_latin = UNSET
        else:
            name_full_latin = self.name_full_latin

        name_given_latin: Union[None, Unset, str]
        if isinstance(self.name_given_latin, Unset):
            name_given_latin = UNSET
        else:
            name_given_latin = self.name_given_latin

        name_family_latin: Union[None, Unset, str]
        if isinstance(self.name_family_latin, Unset):
            name_family_latin = UNSET
        else:
            name_family_latin = self.name_family_latin

        dob: Union[None, Unset, str]
        if isinstance(self.dob, Unset):
            dob = UNSET
        elif isinstance(self.dob, datetime.date):
            dob = self.dob.isoformat()
        else:
            dob = self.dob

        nationality: Union[None, Unset, str]
        if isinstance(self.nationality, Unset):
            nationality = UNSET
        else:
            nationality = self.nationality

        deceased: Union[None, Unset, str]
        if isinstance(self.deceased, Unset):
            deceased = UNSET
        elif isinstance(self.deceased, datetime.date):
            deceased = self.deceased.isoformat()
        else:
            deceased = self.deceased

        additional_names: Union[None, Unset, dict[str, Any]]
        if isinstance(self.additional_names, Unset):
            additional_names = UNSET
        elif isinstance(self.additional_names, PersonModelAdditionalNamesType0):
            additional_names = self.additional_names.to_dict()
        else:
            additional_names = self.additional_names

        additional_details: Union[None, Unset, dict[str, Any]]
        if isinstance(self.additional_details, Unset):
            additional_details = UNSET
        elif isinstance(self.additional_details, PersonModelPersonAdditionalDetails):
            additional_details = self.additional_details.to_dict()
        else:
            additional_details = self.additional_details

        social: Union[None, Unset, dict[str, Any]]
        if isinstance(self.social, Unset):
            social = UNSET
        elif isinstance(self.social, PersonModelSocialMedia):
            social = self.social.to_dict()
        else:
            social = self.social

        historical_names: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.historical_names, Unset):
            historical_names = UNSET
        elif isinstance(self.historical_names, list):
            historical_names = []
            for historical_names_type_0_item_data in self.historical_names:
                historical_names_type_0_item = historical_names_type_0_item_data.to_dict()
                historical_names.append(historical_names_type_0_item)

        else:
            historical_names = self.historical_names

        representing: Union[None, Unset, str]
        if isinstance(self.representing, Unset):
            representing = UNSET
        else:
            representing = self.representing

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        images: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            images = []
            for images_item_data in self.images:
                images_item = images_item_data.to_dict()
                images.append(images_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if status is not UNSET:
            field_dict["status"] = status
        if gender is not UNSET:
            field_dict["gender"] = gender
        if name_full_local is not UNSET:
            field_dict["nameFullLocal"] = name_full_local
        if name_abbreviated is not UNSET:
            field_dict["nameAbbreviated"] = name_abbreviated
        if language_local is not UNSET:
            field_dict["languageLocal"] = language_local
        if name_given_local is not UNSET:
            field_dict["nameGivenLocal"] = name_given_local
        if name_family_local is not UNSET:
            field_dict["nameFamilyLocal"] = name_family_local
        if name_full_latin is not UNSET:
            field_dict["nameFullLatin"] = name_full_latin
        if name_given_latin is not UNSET:
            field_dict["nameGivenLatin"] = name_given_latin
        if name_family_latin is not UNSET:
            field_dict["nameFamilyLatin"] = name_family_latin
        if dob is not UNSET:
            field_dict["dob"] = dob
        if nationality is not UNSET:
            field_dict["nationality"] = nationality
        if deceased is not UNSET:
            field_dict["deceased"] = deceased
        if additional_names is not UNSET:
            field_dict["additionalNames"] = additional_names
        if additional_details is not UNSET:
            field_dict["additionalDetails"] = additional_details
        if social is not UNSET:
            field_dict["social"] = social
        if historical_names is not UNSET:
            field_dict["historicalNames"] = historical_names
        if representing is not UNSET:
            field_dict["representing"] = representing
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if images is not UNSET:
            field_dict["images"] = images

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.images_model import ImagesModel
        from ..models.person_model_additional_names_type_0 import PersonModelAdditionalNamesType0
        from ..models.person_model_organization import PersonModelOrganization
        from ..models.person_model_person_additional_details import PersonModelPersonAdditionalDetails
        from ..models.person_model_person_historical_name import PersonModelPersonHistoricalName
        from ..models.person_model_social_media import PersonModelSocialMedia

        d = dict(src_dict)
        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, PersonModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = PersonModelOrganization.from_dict(_organization)

        _status = d.pop("status", UNSET)
        status: Union[Unset, PersonModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = PersonModelStatus(_status)

        _gender = d.pop("gender", UNSET)
        gender: Union[Unset, PersonModelGender]
        if isinstance(_gender, Unset):
            gender = UNSET
        else:
            gender = PersonModelGender(_gender)

        name_full_local = d.pop("nameFullLocal", UNSET)

        def _parse_name_abbreviated(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_abbreviated = _parse_name_abbreviated(d.pop("nameAbbreviated", UNSET))

        def _parse_language_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        language_local = _parse_language_local(d.pop("languageLocal", UNSET))

        def _parse_name_given_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_given_local = _parse_name_given_local(d.pop("nameGivenLocal", UNSET))

        def _parse_name_family_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_family_local = _parse_name_family_local(d.pop("nameFamilyLocal", UNSET))

        def _parse_name_full_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_full_latin = _parse_name_full_latin(d.pop("nameFullLatin", UNSET))

        def _parse_name_given_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_given_latin = _parse_name_given_latin(d.pop("nameGivenLatin", UNSET))

        def _parse_name_family_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_family_latin = _parse_name_family_latin(d.pop("nameFamilyLatin", UNSET))

        def _parse_dob(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                dob_type_0 = isoparse(data).date()

                return dob_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        dob = _parse_dob(d.pop("dob", UNSET))

        def _parse_nationality(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        nationality = _parse_nationality(d.pop("nationality", UNSET))

        def _parse_deceased(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                deceased_type_0 = isoparse(data).date()

                return deceased_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        deceased = _parse_deceased(d.pop("deceased", UNSET))

        def _parse_additional_names(data: object) -> Union["PersonModelAdditionalNamesType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                additional_names_type_0 = PersonModelAdditionalNamesType0.from_dict(data)

                return additional_names_type_0
            except:  # noqa: E722
                pass
            return cast(Union["PersonModelAdditionalNamesType0", None, Unset], data)

        additional_names = _parse_additional_names(d.pop("additionalNames", UNSET))

        def _parse_additional_details(data: object) -> Union["PersonModelPersonAdditionalDetails", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                additional_details_type_0 = PersonModelPersonAdditionalDetails.from_dict(data)

                return additional_details_type_0
            except:  # noqa: E722
                pass
            return cast(Union["PersonModelPersonAdditionalDetails", None, Unset], data)

        additional_details = _parse_additional_details(d.pop("additionalDetails", UNSET))

        def _parse_social(data: object) -> Union["PersonModelSocialMedia", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                social_type_0 = PersonModelSocialMedia.from_dict(data)

                return social_type_0
            except:  # noqa: E722
                pass
            return cast(Union["PersonModelSocialMedia", None, Unset], data)

        social = _parse_social(d.pop("social", UNSET))

        def _parse_historical_names(data: object) -> Union[None, Unset, list["PersonModelPersonHistoricalName"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                historical_names_type_0 = []
                _historical_names_type_0 = data
                for historical_names_type_0_item_data in _historical_names_type_0:
                    historical_names_type_0_item = PersonModelPersonHistoricalName.from_dict(
                        historical_names_type_0_item_data
                    )

                    historical_names_type_0.append(historical_names_type_0_item)

                return historical_names_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["PersonModelPersonHistoricalName"]], data)

        historical_names = _parse_historical_names(d.pop("historicalNames", UNSET))

        def _parse_representing(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        representing = _parse_representing(d.pop("representing", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        images = []
        _images = d.pop("images", UNSET)
        for images_item_data in _images or []:
            images_item = ImagesModel.from_dict(images_item_data)

            images.append(images_item)

        person_model = cls(
            person_id=person_id,
            organization_id=organization_id,
            organization=organization,
            status=status,
            gender=gender,
            name_full_local=name_full_local,
            name_abbreviated=name_abbreviated,
            language_local=language_local,
            name_given_local=name_given_local,
            name_family_local=name_family_local,
            name_full_latin=name_full_latin,
            name_given_latin=name_given_latin,
            name_family_latin=name_family_latin,
            dob=dob,
            nationality=nationality,
            deceased=deceased,
            additional_names=additional_names,
            additional_details=additional_details,
            social=social,
            historical_names=historical_names,
            representing=representing,
            external_id=external_id,
            updated=updated,
            added=added,
            images=images,
        )

        return person_model



from enum import Enum


class SeasonSeriesListSeriesType(str, Enum):
    BEST_OF = "BEST_OF"
    HEAD_TO_HEAD = "HEAD_TO_HEAD"
    HOME_AND_AWAY = "HOME_AND_AWAY"
    KNOCKOUT = "KNOCKOUT"
    TOURNAMENT = "TOURNAMENT"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.conduct_model_conduct_penalty_result_penalty_type import ConductModelConductPenaltyResultPenaltyType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ConductModelConductPenaltyResult")


@_attrs_define
class ConductModelConductPenaltyResult:
    """
    Attributes:
        penalty_type (Union[Unset, ConductModelConductPenaltyResultPenaltyType]): Penalty type Example: WEEK.
        penalty_value (Union[None, Unset, int]): Penalty value Example: 6.
    """

    penalty_type: Union[Unset, ConductModelConductPenaltyResultPenaltyType] = UNSET
    penalty_value: Union[None, Unset, int] = UNSET

    def to_dict(self) -> dict[str, Any]:
        penalty_type: Union[Unset, str] = UNSET
        if not isinstance(self.penalty_type, Unset):
            penalty_type = self.penalty_type.value

        penalty_value: Union[None, Unset, int]
        if isinstance(self.penalty_value, Unset):
            penalty_value = UNSET
        else:
            penalty_value = self.penalty_value

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if penalty_type is not UNSET:
            field_dict["penaltyType"] = penalty_type
        if penalty_value is not UNSET:
            field_dict["penaltyValue"] = penalty_value

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _penalty_type = d.pop("penaltyType", UNSET)
        penalty_type: Union[Unset, ConductModelConductPenaltyResultPenaltyType]
        if isinstance(_penalty_type, Unset):
            penalty_type = UNSET
        else:
            penalty_type = ConductModelConductPenaltyResultPenaltyType(_penalty_type)

        def _parse_penalty_value(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        penalty_value = _parse_penalty_value(d.pop("penaltyValue", UNSET))

        conduct_model_conduct_penalty_result = cls(
            penalty_type=penalty_type,
            penalty_value=penalty_value,
        )

        return conduct_model_conduct_penalty_result



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.match_person_statistics_model_position_type_1 import MatchPersonStatisticsModelPositionType1
from ..models.match_person_statistics_model_position_type_2_type_1 import MatchPersonStatisticsModelPositionType2Type1
from ..models.match_person_statistics_model_position_type_3_type_1 import MatchPersonStatisticsModelPositionType3Type1
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.match_person_statistics_model_entity import MatchPersonStatisticsModelEntity
    from ..models.match_person_statistics_model_fixture import MatchPersonStatisticsModelFixture
    from ..models.match_person_statistics_model_organization import MatchPersonStatisticsModelOrganization
    from ..models.match_person_statistics_model_person import MatchPersonStatisticsModelPerson
    from ..models.match_person_statistics_model_statistics import MatchPersonStatisticsModelStatistics


T = TypeVar("T", bound="MatchPersonStatisticsModel")


@_attrs_define
class MatchPersonStatisticsModel:
    """
    Attributes:
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, MatchPersonStatisticsModelPerson]): The person information
        entity_id (Union[None, UUID, Unset]): The unique identifier of the team Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, MatchPersonStatisticsModelEntity]): The team information
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, MatchPersonStatisticsModelFixture]): The match
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, MatchPersonStatisticsModelOrganization]): The organization that this match person
            statistics belongs to
        statistics (Union[Unset, MatchPersonStatisticsModelStatistics]):
        bib (Union[None, Unset, str]): The number displayed on the jersey Example: 34.
        position (Union[MatchPersonStatisticsModelPositionType1, MatchPersonStatisticsModelPositionType2Type1,
            MatchPersonStatisticsModelPositionType3Type1, None, Unset]): Playing position
            >- None None
            >- `CB` Center Backcourt
            >- `D` Defensive Specialist
            >- `G` Goalkeeper
            >- `LB` Left Backcourt
            >- `LW` Left Wingman
            >- `P` Pivot
            >- `RB` Right Backcourt
            >- `RW` Right Wingman
             Example: G.
        did_not_play_reason (Union[None, Unset, str]): The reason the player didn't play Example: COACHES_DECISION.
        starter (Union[Unset, bool]):  Example: True.
        participated (Union[Unset, bool]): Did the person actually participate in the the match Example: True.
        is_player (Union[Unset, bool]): Is this person a player Example: True.
        is_team_official (Union[Unset, bool]): Is this person a team official Example: True.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "MatchPersonStatisticsModelPerson"] = UNSET
    entity_id: Union[None, UUID, Unset] = UNSET
    entity: Union[Unset, "MatchPersonStatisticsModelEntity"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "MatchPersonStatisticsModelFixture"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "MatchPersonStatisticsModelOrganization"] = UNSET
    statistics: Union[Unset, "MatchPersonStatisticsModelStatistics"] = UNSET
    bib: Union[None, Unset, str] = UNSET
    position: Union[
        MatchPersonStatisticsModelPositionType1,
        MatchPersonStatisticsModelPositionType2Type1,
        MatchPersonStatisticsModelPositionType3Type1,
        None,
        Unset,
    ] = UNSET
    did_not_play_reason: Union[None, Unset, str] = UNSET
    starter: Union[Unset, bool] = UNSET
    participated: Union[Unset, bool] = UNSET
    is_player: Union[Unset, bool] = UNSET
    is_team_official: Union[Unset, bool] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        entity_id: Union[None, Unset, str]
        if isinstance(self.entity_id, Unset):
            entity_id = UNSET
        elif isinstance(self.entity_id, UUID):
            entity_id = str(self.entity_id)
        else:
            entity_id = self.entity_id

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        statistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        bib: Union[None, Unset, str]
        if isinstance(self.bib, Unset):
            bib = UNSET
        else:
            bib = self.bib

        position: Union[None, Unset, str]
        if isinstance(self.position, Unset):
            position = UNSET
        elif isinstance(self.position, MatchPersonStatisticsModelPositionType1):
            position = self.position.value
        elif isinstance(self.position, MatchPersonStatisticsModelPositionType2Type1):
            position = self.position.value
        elif isinstance(self.position, MatchPersonStatisticsModelPositionType3Type1):
            position = self.position.value
        else:
            position = self.position

        did_not_play_reason: Union[None, Unset, str]
        if isinstance(self.did_not_play_reason, Unset):
            did_not_play_reason = UNSET
        else:
            did_not_play_reason = self.did_not_play_reason

        starter = self.starter

        participated = self.participated

        is_player = self.is_player

        is_team_official = self.is_team_official

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if statistics is not UNSET:
            field_dict["statistics"] = statistics
        if bib is not UNSET:
            field_dict["bib"] = bib
        if position is not UNSET:
            field_dict["position"] = position
        if did_not_play_reason is not UNSET:
            field_dict["didNotPlayReason"] = did_not_play_reason
        if starter is not UNSET:
            field_dict["starter"] = starter
        if participated is not UNSET:
            field_dict["participated"] = participated
        if is_player is not UNSET:
            field_dict["isPlayer"] = is_player
        if is_team_official is not UNSET:
            field_dict["isTeamOfficial"] = is_team_official
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.match_person_statistics_model_entity import MatchPersonStatisticsModelEntity
        from ..models.match_person_statistics_model_fixture import MatchPersonStatisticsModelFixture
        from ..models.match_person_statistics_model_organization import MatchPersonStatisticsModelOrganization
        from ..models.match_person_statistics_model_person import MatchPersonStatisticsModelPerson
        from ..models.match_person_statistics_model_statistics import MatchPersonStatisticsModelStatistics

        d = dict(src_dict)
        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, MatchPersonStatisticsModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = MatchPersonStatisticsModelPerson.from_dict(_person)

        def _parse_entity_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                entity_id_type_0 = UUID(data)

                return entity_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        entity_id = _parse_entity_id(d.pop("entityId", UNSET))

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, MatchPersonStatisticsModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = MatchPersonStatisticsModelEntity.from_dict(_entity)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, MatchPersonStatisticsModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = MatchPersonStatisticsModelFixture.from_dict(_fixture)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, MatchPersonStatisticsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = MatchPersonStatisticsModelOrganization.from_dict(_organization)

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, MatchPersonStatisticsModelStatistics]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = MatchPersonStatisticsModelStatistics.from_dict(_statistics)

        def _parse_bib(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        bib = _parse_bib(d.pop("bib", UNSET))

        def _parse_position(
            data: object,
        ) -> Union[
            MatchPersonStatisticsModelPositionType1,
            MatchPersonStatisticsModelPositionType2Type1,
            MatchPersonStatisticsModelPositionType3Type1,
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_1 = MatchPersonStatisticsModelPositionType1(data)

                return position_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_2_type_1 = MatchPersonStatisticsModelPositionType2Type1(data)

                return position_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_3_type_1 = MatchPersonStatisticsModelPositionType3Type1(data)

                return position_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    MatchPersonStatisticsModelPositionType1,
                    MatchPersonStatisticsModelPositionType2Type1,
                    MatchPersonStatisticsModelPositionType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        position = _parse_position(d.pop("position", UNSET))

        def _parse_did_not_play_reason(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        did_not_play_reason = _parse_did_not_play_reason(d.pop("didNotPlayReason", UNSET))

        starter = d.pop("starter", UNSET)

        participated = d.pop("participated", UNSET)

        is_player = d.pop("isPlayer", UNSET)

        is_team_official = d.pop("isTeamOfficial", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        match_person_statistics_model = cls(
            person_id=person_id,
            person=person,
            entity_id=entity_id,
            entity=entity,
            fixture_id=fixture_id,
            fixture=fixture,
            organization_id=organization_id,
            organization=organization,
            statistics=statistics,
            bib=bib,
            position=position,
            did_not_play_reason=did_not_play_reason,
            starter=starter,
            participated=participated,
            is_player=is_player,
            is_team_official=is_team_official,
            updated=updated,
            added=added,
        )

        return match_person_statistics_model



from enum import Enum


class SeasonRosterDetailStatus(str, Enum):
    ACTIVE = "ACTIVE"
    INJURED = "INJURED"
    OTHER_NOT_PARTICIPATING = "OTHER_NOT_PARTICIPATING"
    OUT = "OUT"
    SUSPENSED = "SUSPENSED"

    def __str__(self) -> str:
        return str(self.value)
